@@ -3,7 +3,7 @@
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 # Copyright (c) 2016-2017 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin.pm v1.029 Sat Feb  4 00:48:25 PST 2017 $
+# $Id: lib/Business/Bitcoin.pm v1.033 Sun Mar 26 02:00:37 PDT 2017 $
 
 use strict;
 
@@ -18,7 +18,7 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.029 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.033 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -35,7 +35,9 @@ sub new {
 		                                         amount int NOT NULL,
                                                          address text,
                                                          refid text UNIQUE,
-		                                         created int NOT NULL
+		                                         created int NOT NULL,
+                                                         processed int,
+                                                         status text
 		                                        );');
       return undef unless $db->do('CREATE INDEX idx_requests_address ON requests(address);');
       return undef unless $db->do('CREATE INDEX idx_requests_refid ON requests(refid);');
@@ -90,8 +92,8 @@ Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.029 $
- $Date: Sat Feb  4 00:48:25 PST 2017 $
+ $Revision: 1.033 $
+ $Date: Sun Mar 26 02:00:37 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -124,9 +126,9 @@ wallet private key offline.
 =head1 HOW TO USE
 
 To start receiving Bitcoin payments online, create an HD wallet using
-any HD wallet app (e.g. Electrum, Bitcoin Armory), get the
-"Master Public Key" for the wallet (a string beginning with "xpub")
-and plug it into the constructor's XPUB argument).
+a BIP-32 HD wallet app such as Electrum, get the "Master Public Key"
+for the wallet (a string beginning with "xpub") and plug it into the
+constructor's XPUB argument.
 
 Now you can receive online payments as outlined above, while keeping
 your private key secure offline. You should still take all precautions
@@ -134,6 +136,11 @@ to ensure that your XPUB key on the server is also safe, as its
 compromise can weaken your security, though it can't in itself lead to
 the loss of any Bitcoin.
 
+Currently the key derivation path used in this module is m/0/i which
+corresponds to what Electrum uses. More flexibility in selecting the
+derivation path and presets for paths used by other wallets will be
+implemented in future versions.
+
 =head1 METHODS
 
 =head2 new
