@@ -3,7 +3,7 @@
 # Business::Bitcoin::Request - Bitcoin payment request
 # Copyright (c) 2016-2017 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin/Request.pm v1.029 Sat Feb  4 00:48:25 PST 2017 $
+# $Id: lib/Business/Bitcoin/Request.pm v1.033 Sun Mar 26 02:00:37 PDT 2017 $
 
 use warnings;
 use strict;
@@ -21,7 +21,7 @@ use Crypt::RIPEMD160;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.029 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.033 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %args) = @_;
@@ -30,13 +30,15 @@ sub new {
   my $timestamp = time;
   my $index = defined $args{StartIndex} ? $args{StartIndex} : 'NULL';
   my $refid = defined $args{Reference} ? "'$args{Reference}'" : 'NULL';
-  return undef unless $db->do("INSERT INTO requests values ($index, '$args{Amount}', NULL, $refid, '$timestamp');");
+  return undef unless $db->do("INSERT INTO requests values ($index, '$args{Amount}', NULL, $refid, '$timestamp', NULL, NULL);");
   $index = $db->last_insert_id('%', '%', 'requests', 'reqid');
   $ENV{PATH} = undef;
   return undef unless my $address = _getaddress($args{_BizBTC}->xpub, $index);
   my $rows = $db->do("UPDATE requests set address='$address' where reqid='$index';");
   bless { Address => $address,
+	  ID => $index,
 	  Amount => $args{Amount},
+	  DB => $db,
 	  Reference => $args{Reference},
 	  Confirmations => defined $args{Confirmations} ? $args{Confirmations} : 5,
 	  Created => $timestamp }, $class;
@@ -54,15 +56,33 @@ sub _find {
   my ($class, %args) = @_;
   return unless defined $args{Address} or defined $args{Reference};
   return if defined $args{Address} and defined $args{Reference};
+  return unless defined $args{_BizBTC} and $args{_BizBTC}->db->ping;
 
-  my $query = 'SELECT address,amount,refid,created from requests WHERE ' .
+  my $query = 'SELECT reqid,address,amount,refid,created,processed,status from requests WHERE ' .
     (defined $args{Address} ? "address='$args{Address}';" : "refid='$args{Reference}';");
-  my ($address, $amount, $refid, $created) = $args{_BizBTC}->db->selectrow_array($query);
+  my ($reqid, $address, $amount, $refid, $created, $processed, $status) = $args{_BizBTC}->db->selectrow_array($query);
   bless { Address => $address,
 	  Amount => $amount,
 	  Reference => $refid,
+	  ID => $reqid,
+	  DB => $args{_BizBTC}->db,,
 	  Confirmations => defined $args{Confirmations} ? $args{Confirmations} : 5,
-	  Created => $created }, $class;
+	  Created => $created,
+	  Processed => $processed,
+	  Status => $status
+	}, $class;
+}
+
+sub commit {
+  my $self = shift;
+  my $processed = $self->processed;
+  my $status = $self->status;
+  my @updates;
+  push @updates, "processed = '" . $processed . "'" if $processed;
+  push @updates, "status = '" . $status . "'" if $status;
+  return 1 unless my $updates = join ',',@updates;
+  return undef unless $self->db->do("UPDATE requests SET $updates;");
+  return 1;
 }
 
 sub _getaddress {
@@ -129,12 +149,15 @@ sub _encode58 {
 sub AUTOLOAD {
   my $self = shift; (my $auto = $AUTOLOAD) =~ s/.*:://;
   return if $auto eq 'DESTROY';
-  if ($auto =~ /^(confirmations)$/x) {
-    $self->{"\u$auto"} = shift if (defined $_[0]);
+  if ($auto =~ /^(confirmations|processed|status)$/x and defined $_[0]) {
+    $self->{"\u$auto"} = shift;
   }
-  if ($auto =~ /^(amount|address|reference|version|created|confirmations)$/x) {
+  if ($auto =~ /^(reqid|amount|address|reference|version|created|confirmations|processed|status)$/x) {
     return $self->{"\u$auto"};
   }
+  if ($auto =~ /^(db|id)$/x) {
+    return $self->{"\U$auto"};
+  }
   else {
     die "Could not AUTOLOAD method $auto.";
   }
@@ -148,8 +171,8 @@ Business::Bitcoin::Request - Bitcoin payment request
 
 =head1 VERSION
 
- $Revision: 1.029 $
- $Date: Sat Feb  4 00:48:25 PST 2017 $
+ $Revision: 1.033 $
+ $Date: Sun Mar 26 02:00:37 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -173,6 +196,11 @@ Not intended to be called directly. Business::Bitcoin::Request objects
 should be created by calling the request method on a Business::Bitcoin
 object.
 
+=head2 commit
+
+Commit the Request object to the requests database. Only the
+'processed' and 'status' fields are updated in the database.
+
 =head2 verify
 
 Verify that the request has been paid. Returns true if the request has
@@ -199,12 +227,26 @@ The Bitcoin receiving address for the payment request. Read only.
 
 =head2 created
 
-The timestamp of when the request was created. Read only.
+The timestamp of when the request was created. Stored as an int in the
+requests database. Read only.
 
 =head2 reference
 
 An optional reference ID for the request, to facilitate integration
-with existing order systems. Read only.
+with existing order systems. Stored as a text field in the requests
+database. Read only.
+
+=head2 processed
+
+An optional property for applications to record the timestamp of when
+the transaction was processed. Stored as an int in the requests
+database. Read/write.
+
+=head2 status
+
+An optional property that can be used to record the status of the
+transaction ('processed', 'shipped', 'refunded', etc.). Stored as a
+text field in the requests database. Read/write.
 
 =head2 version
 
